@@ -3,9 +3,5 @@ from idp_authentication.users.domain.entities import UserRole
 from idp_authentication.users.domain.ports.repository import UserRoleRepositoryPort
 
 
-class UserRoleRepository(UserRoleRepositoryPort, BaseRepository):
+class UserRoleRepository(BaseRepository, UserRoleRepositoryPort):
     entity = UserRole
-
-    def delete(self, record: UserRole) -> None:
-        self.session.delete(record)
-        self.session.commit()
