@@ -1,5 +1,5 @@
 import abc
-from typing import Any, Iterable, List
+from typing import List
 
 from idp_authentication.users.domain.entities.user import User
 
@@ -13,12 +13,6 @@ class RepositoryPort(abc.ABC):
     def get_first(self, **filters):
         """Get the first record, after applying filters"""
 
-    @abc.abstractmethod
-    def filter_by_identifier(
-        self, identifier_attr: str, identifier_values: Iterable[Any]
-    ):
-        """Filter by identifier values"""
-
     @abc.abstractmethod
     def all(self):
         """Get all records"""
@@ -50,12 +44,3 @@ class UserRoleRepositoryPort(RepositoryPort, abc.ABC):
     @abc.abstractmethod
     def delete(self, record):
         """Delete a record."""
-
-
-class AppEntityRepositoryPort(RepositoryPort, abc.ABC):
-    """App entity repository port."""
-
-    @classmethod
-    @abc.abstractmethod
-    def get_idp_identifier_attr(cls) -> str:
-        """Get the identifier attribute for the app entity."""
