@@ -26,7 +26,3 @@ class UnitOfWorkPort(ABC):
 class UsersUnitOfWorkPort(UnitOfWorkPort, ABC):
     user_repository: UserRepositoryPort
     user_role_repository: UserRoleRepositoryPort
-
-
-class AuthUnitOfWorkPort(UnitOfWorkPort, ABC):
-    user: UserRepositoryPort
